void oled_menu() {
  lcd.clear();
  lcd.setCursor(3, 0);
  print_lcd(7);    // НАЛИВАТОР+
  lcd.setCursor(15, 0);
  lcd.write(7);
  lcd.setCursor(0, 1);
  print_lcd(67);// >
  lcd.setCursor(15, 1);
  print_lcd(66);// <
  switch (Menu) {
    case 0:
      lcd.setCursor(6, 1);
      print_lcd(8);//  АВТО
      break;
    case 1:
      lcd.setCursor(3, 1);
      print_lcd(9);//  МУЛТИРАЗЛИВ
      break;
    case 2:
      lcd.setCursor(5, 1);
      print_lcd(10);//  ПЛЕЕР
      break;
    case 3:
      lcd.setCursor(3, 1);
      print_lcd(11);//  НАСТРОЙКИ
      break;
  }
}



void menu_nastr() {
  lcd.clear();
  lcd.setCursor(3, 0);
  print_lcd(11);//  НАСТРОЙКА
  lcd.setCursor(15, 0);
  lcd.write(7);
  lcd.setCursor(0, 1);
  print_lcd(67);//  >
  lcd.setCursor(15, 1);
  print_lcd(66);//  <
  switch (subNastr) {
    case 1:
      lcd.setCursor(4, 1);
      print_lcd(12);// ПРОМЫВКА
      break;
    case 2:
      lcd.setCursor(3, 1);
      print_lcd(13);// МУЛТИРАЗЛИВ
      break;
    case 3:
      lcd.setCursor(5, 1);
      print_lcd(14);//  ТОСТЫ
      break;

    case 4:
      lcd.setCursor(2, 1);
      print_lcd(15);//  МЕНЮ  СЕРВО
      break;

    case 5:
      lcd.setCursor(2, 1);
      print_lcd(16);//  ЯРКОСТЬ  LED
      break;

    case 6:
      lcd.setCursor(3, 1);
      print_lcd(17);//  АВТО-БАРМЕН
      break;


    case 7:
      lcd.setCursor(1, 1);
      print_lcd(18);//  НАПРЯЖЕНИЕ АКБ
      break;

    case 8:
      lcd.setCursor(3, 1);
      print_lcd(19);//  ТАЙМЕР СНА
      break;

    case 9:
      lcd.setCursor(2, 1);
      print_lcd(20);// КАЛИБР.ПОМПЫ
      break;
  }
}



// Меню Авто режим
void oled_auto() {
  lcd.clear();
  lcd.setCursor(0, 0);
  print_lcd(21);//  HАЛИTЬ ПO   ml
  lcd.setCursor(10, 0);
  lcd.print(Drink, DEC);
  lcd.setCursor(15, 0);
  lcd.write(7);
  lcd.setCursor(0, 1);
  if (Drink < 25) {
    print_lcd(22);//  HИ O ЧEM
  } else if (Drink < 30) {
    print_lcd(23);//  ПO ЧУTЬ - ЧУTЬ
  } else if (Drink < 40) {
    print_lcd(24);//  B CAMЫЙ PAЗ
  } else if (Drink < 45) {
    print_lcd(25);//  ПО  ПОЛНОЙ
  } else {
    print_lcd(26);//  ДО КРАЕВ
  }
  if (barMan) {
    lcd.setCursor(15, 1);
    print_lcd(39);//  B
  }
}

// Меню налива
void oled_naliv() {
  lcd.clear();
  lcd.setCursor(2, 0);
  print_lcd(27);//  НАЛИВАЮ     ml
  lcd.setCursor(0, 1);
  print_lcd(28);//  В  -Ю РЮМКУ   ml
}

// Меню налито
void oled_nalito() {
  lcd.clear();
  if (MenuFlag == 2) {
    lcd.setCursor(5, 0);
    print_lcd(29); //  HАЛИТО
  } else {
    lcd.setCursor(0, 0);
    print_lcd(30);//  HАЛИТО ПО     ml
    lcd.setCursor(11, 0);
    lcd.print(Drink, DEC);
  }
  lcd.setCursor(0, 1);
  print_lcd(31);//    В   РЮМ
  lcd.setCursor(5, 1);
  lcd.print(DrinkCount, DEC);
  if (DrinkCount == 1) {
    lcd.setCursor(10, 1);
    print_lcd(32);//  КУ
  } else if (DrinkCount <= 4 ) {
    lcd.setCursor(10, 1);
    print_lcd(33);//  КИ
  } else {
    lcd.setCursor(10, 1);
    print_lcd(34);//  ОК
  }
}

// Меню настройки серво
void servo_calibr(uint8_t subServo) {
  if (subServo == 1) {
    lcd.clear();
    lcd.setCursor(4, 0);
    print_lcd(35);//  -я рюмка
    lcd.setCursor(3, 1);
    print_lcd(36);//  поз.:
    subServo = 2;
  }
  if (subServo == 2) {
    lcd.setCursor(3, 0);
    lcd.print((count + 1), DEC);
    subServo = 3;
  }
  if (subServo == 3) {
    lcd.setCursor(10, 1);
    print_lcd(4);//   пробел 3
    lcd.setCursor(9, 1);
    lcd.print(servoPos, DEC);
  }
}


void multi_naliv() {
  lcd.clear();
  lcd.setCursor(0, 0);
  print_lcd(37);//  1-   2-   3-
  lcd.setCursor(15, 0);
  lcd.write(7);
  lcd.setCursor(2, 0);
  lcd.print(ManDrink[0], DEC);
  lcd.setCursor(7, 0);
  lcd.print(ManDrink[1], DEC);
  lcd.setCursor(12, 0);
  lcd.print(ManDrink[2], DEC);
  lcd.setCursor(0, 1);
  print_lcd(38);//   4-   5-   6-
  lcd.setCursor(2, 1);
  lcd.print(ManDrink[3], DEC);
  lcd.setCursor(7, 1);
  lcd.print(ManDrink[4], DEC);
  lcd.setCursor(12, 1);
  lcd.print(ManDrink[5], DEC);
  if (barMan) {
    lcd.setCursor(15, 1);
    print_lcd(39);//  B
  }
}

void multi_naliv2() {
  lcd.clear();
  lcd.setCursor(0, 1);
  if (ManDrink[(ManRum - 1)] < 25) {
    print_lcd(22);//  НИ О ЧЕМ
  } else if (ManDrink[(ManRum - 1)] < 30) {
    print_lcd(23);//  ПО ЧУТЬ - ЧУТЬ
  } else if (ManDrink[(ManRum - 1)] < 40) {
    print_lcd(24);//  В САМЫЙ  РАЗ
  } else if (ManDrink[(ManRum - 1)] < 45) {
    print_lcd(25);//  ПО  ПОЛНОЙ
  } else {
    print_lcd(26);//  ДО КРАЕВ
  }
  lcd.setCursor(0, 0);
  lcd.print(ManRum, DEC);
  lcd.setCursor(1, 0);
  print_lcd(40);// -Я РЮМКА:   ml
  lcd.setCursor(10, 0);
  lcd.print(ManDrink[(ManRum - 1)], DEC);
}

void menu_tost() {
  lcd.clear();
  lcd.setCursor(5, 0);
  print_lcd(14);// ТОСТЫ
  switch (subMenu) {
    case 1:
      lcd.setCursor(3, 1);
      print_lcd(41);// ГР.ОЗВУЧКИ
      break;

    case 2:
      lcd.setCursor(0, 1);
      print_lcd(42);//  ПЕРЕМЕШАТЬ ТРЕКИ
      break;

    case 3:
      lcd.setCursor(0, 1);
      print_lcd(43);//  ПАПКА С ТРЕКАМИ
      break;

  }
}

void num_folder() {
  lcd.clear();
  lcd.setCursor(3, 0);
  print_lcd(44);//  ПАПКА
  lcd.setCursor(11, 0);
  lcd.print(folder, DEC);
  lcd.setCursor(2, 1);
  print_lcd(45);//  ТРЕКОВ
  lcd.setCursor(11, 1);
  if (tracks == -1) {
    print_lcd(46); //  НЕТ
  } else {
    lcd.print(tracks, DEC);
  }
}
void menu_play() {
  lcd.clear();
  lcd.setCursor(0, 0);
  print_lcd(44);//  ПАПКА:
  lcd.setCursor(6, 0);
  lcd.print(folder2, DEC);
  lcd.setCursor(9, 0);
  print_lcd(68); // VOL;
  lcd.setCursor(12, 0);
  lcd.print(volume2, DEC);
  lcd.setCursor(15, 0);
  lcd.write(7);
  lcd.setCursor(11, 1);
  if (player) {
    print_lcd(47);//  PLAY
  }
  lcd.setCursor(0, 1);
  print_lcd(69);//  ТР:
  if (tracks2 == -1) {
    lcd.setCursor(3, 1);
    print_lcd(46);// НЕТ
    lcd.setCursor(7, 1);
    print_lcd(4);// пробел
  } else {
    lcd.setCursor(3, 1);
    lcd.print(tracks2, DEC);
    lcd.setCursor(7, 1);
    lcd.print(num2, DEC);
  }
  if (folTra == 1) {   // галочка на выборе папки
    lcd.setCursor(8, 0);
  } else if (folTra == 2) { // галочка на треках
    lcd.setCursor(10, 1);
  } else if (folTra == 3) {  // галочка на громкости
    lcd.setCursor(14, 0);
  } else if (folTra == 4) {  //  галрчка нв вкл-выкл play
    lcd.setCursor(15, 1);
  }
  print_lcd(66);//  <
}



void menu_servo() {
  lcd.clear();
  lcd.setCursor(0, 0);
  print_lcd(48);//  НАСТРОЙКИ  СЕРВО
  switch (subMenu) {
    case 1:
      lcd.setCursor(3, 1);
      print_lcd(49);//  КАЛИБРОВКА
      break;

    case 2:
      lcd.setCursor(4, 1);
      print_lcd(50);//  СКОРОСТЬ
      break;

  }
}


void menu_vol(uint8_t subVol) {
  if (subVol == 0) {
    lcd.clear();
    lcd.setCursor(0, 1);
    print_lcd(51);//  ГРОМКОСТЬ
    subVol = 1;
  }
  if (subVol == 1) {
    lcd.setCursor(12, 1);
    print_lcd(4);//  пробел 3
    lcd.setCursor(13, 1);
    lcd.print(volume, DEC);
  }
}


void menu_brigh(uint8_t subBrigh) {
  if (subBrigh == 0) {
    lcd.clear();
    lcd.setCursor(0, 0);
    print_lcd(52);//  ЯРКОСТЬ LED
    lcd.setCursor(10, 0);
     print_lcd(70);//  SHOW
     lcd.setCursor(4, 1);
    if(ledShowOn){
       print_lcd(55);// ВКЛ.
    }else{
       print_lcd(56);// ВЫКЛ.
    }
    subBrigh = 1;
  }
  if (subBrigh == 1) {
    lcd.setCursor(2, 1);
    print_lcd(4);// пробел 3
    lcd.setCursor(2, 1);
    lcd.print((map(bright, 0, 254, 0, 99)), DEC);
  }
}

void menu_promivka(uint8_t subPromivka) {
  lcd.clear();
  lcd.setCursor(0, 0);
  print_lcd(53);//  П Р О М Ы В К А
  if (subPromivka == 1) {
    lcd.setCursor(2, 1);
    print_lcd(54);//  >>>>>>>>>>>>
  } else if (subPromivka == 2) {
    lcd.setCursor(5, 1);
    lcd.print(Procent, DEC);
    lcd.setCursor(10, 1);
    print_lcd(64);// мс
  }
}

void bar_man() {
  lcd.clear();
  lcd.setCursor(0, 1);
  if (barMan) {
    print_lcd(55);// ВКЛ.
  } else {
    print_lcd(56);// ВЫКЛ.
  }
}

void mix_track() {
  lcd.clear();
  lcd.setCursor(0, 1);
  if (mixTracks == 1) {
    print_lcd(55);// ВКЛ.
  } else {
    print_lcd(56);// ВЫКЛ.
  }
}

void servo_speed(uint8_t subSS) {
  if (subSS == 0) {
    lcd.clear();
    lcd.setCursor(0, 0);
    print_lcd(50);//  СКОРОСТЬ
    subSS = 1;
  }
  if (subSS == 1) {
    lcd.setCursor(12, 0);
    print_lcd(4);// пробел 3
    lcd.setCursor(12, 0);
    lcd.print((map(speedSer, 2, 30, 30, 2)), DEC);
  }
}

void bat_volt() {
  lcd.clear();
  lcd.setCursor(3, 0);
  print_lcd(57);//  НАПРЯЖЕНИЕ
  lcd.setCursor(5, 1);
  lcd.print((value * ADC_U_COEFF), 2);
  lcd.setCursor(10, 1);
  print_lcd(58);// V

}

void sleep_time(uint8_t subTime) {
  if (subTime == 0) {
    lcd.clear();
    lcd.setCursor(1, 0);
    print_lcd(59);//  ЗАСНУТЬ ЧЕРЕЗ
    subTime = 1;
  }
  if (subTime == 1) {
    if (sleepTime == 0) {
      lcd.setCursor(0, 1);
      print_lcd(56);//  ВЫКЛ.
    } else {
      lcd.setCursor(5, 1);
      lcd.print((map(sleepTime, 0, 20, 0, 10)), DEC);
      lcd.setCursor(6, 1);
      if (sleepTime % 2 != 0) {
        print_lcd(60);//  .30
      } else {
        print_lcd(61);//  .00
      }
      lcd.setCursor(9, 1);
      print_lcd(62);//  МИН.
    }
  }
}


void kalibr_pump(uint8_t subPump) {
  if (subPump == 0) {
    lcd.clear();
    lcd.setCursor(1, 0);
    print_lcd(63);//  НАЛИВ 50ml ЗА:
    lcd.setCursor(8, 1);
    print_lcd(64);//  мс
    subPump = 1;
  }
  if (subPump == 1) {
    lcd.setCursor(3, 1);
    lcd.print(time50ml, DEC);
    lcd.setCursor(12, 1);
    print_lcd(65);//  ml
  }
}
